source@mandoc.bsd.lv
 help / color / mirror / Atom feed
* mdocml: Skip leading escape sequences in man_deroff().
@ 2014-03-23 20:57 schwarze
  0 siblings, 0 replies; only message in thread
From: schwarze @ 2014-03-23 20:57 UTC (permalink / raw)
  To: source

Log Message:
-----------
Skip leading escape sequences in man_deroff().  Helps indexing of   
some manuals containing overzealous escaping in their NAME section.

Modified Files:
--------------
    mdocml:
        man.c

Revision Data
-------------
Index: man.c
===================================================================
RCS file: /usr/vhosts/mdocml.bsd.lv/cvs/mdocml/man.c,v
retrieving revision 1.126
retrieving revision 1.127
diff -Lman.c -Lman.c -u -p -r1.126 -r1.127
--- man.c
+++ man.c
@@ -720,11 +720,18 @@ man_deroff(char **dest, const struct man
 		return;
 	}
 
 	/* Skip leading whitespace. */
 
-	for (cp = n->string; '\0' != *cp; cp++)
-		if (0 == isspace((unsigned char)*cp))
+	cp = n->string;
+	while ('\0' != *cp) {
+		if ('\\' == *cp) {
+			cp++;
+			mandoc_escape((const char **)&cp, NULL, NULL);
+		} else if (isspace((unsigned char)*cp))
+			cp++;
+		else
 			break;
+	}
 
 	/* Skip trailing whitespace. */
 
@@ -720,11 +720,18 @@ man_deroff(char **dest, const struct man
 	}
 
-	/* Skip leading whitespace. */
+	/* Skip leading whitespace and escape sequences. */
 
--
 To unsubscribe send an email to source+unsubscribe@mdocml.bsd.lv

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2014-03-23 20:57 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2014-03-23 20:57 mdocml: Skip leading escape sequences in man_deroff() schwarze

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).